#app[data-v-1e5ac138]{font-family:Avenir,Helvetica,Arial,sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;color:#2c3e50;margin-top:0}.graph[data-v-1e5ac138]{background-color:#fefefe;border:1px solid #e8e8e8;padding:5px}.feedback[data-v-1e5ac138]{font-size:x-small;float:right}.selected[data-v-1e5ac138]{float:right;font-size:x-small}.debuginfo[data-v-1e5ac138]{display:block;visibility:hidden;background-color:coral;color:#fff;font-size:10px}#sigma-container[data-v-1e5ac138]{position:relative;height:400px;border:1px solid #e8e8e8;border-radius:8px}button+button[data-v-1e5ac138]{margin-left:10px}.err__title[data-v-9ae37d8b],.err__msg[data-v-9ae37d8b],body{margin:0}#app{color:var(--text-color);font-family:var(--font);-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}
